<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.UI.ViewManagement.Core

Windows Runtime (WinRT) APIs for for the `Windows.UI.ViewManagement.Core` namespace.

This package provides the `winrt.windows.ui.viewmanagement.core` module.
